<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * Arabic language file
 *
 * @author Khalid <khalid.aljahil@gmail.com>
 * @author Yaman Hokan <always.smile.yh@hotmail.com>
 * @author Usama Akkad <uahello@gmail.com>
 */
$lang['menu']                  = 'الإعدادات';
$lang['error']                 = 'لم تحدث الاعدادات بسبب قيمة غير صالحة، رجاء راجع تغييراتك ثم ارسلها.
<br />القيم الخاطئة ستظهر محاطة بحدود حمراء.';
$lang['updated']               = 'رفعت الاعدادات بنجاح.';
$lang['nochoice']              = '(لا خيارات اخرى متاحة)';
$lang['locked']                = 'تعذر تحديث ملف الاعدادات، إن لم يكن ذلك مقصودا، <br />
تأكد من صحة اسم و صلاحيات ملف الاعدادات المحلي.';
$lang['danger']                = 'خطر: تغيير هذا الخيار قد يؤدي إلى تعذر الوصول للويكي و قائمة الاعدادات.';
$lang['warning']               = 'تحذير: تغييرهذا الخيار قد يؤدي لسلوك غير متوقع.';
$lang['security']              = 'تحذير أمني: تغيير هذا الخيار قد يؤدي إلى مخاطرة أمنية.';
$lang['_configuration_manager'] = 'مدير الاعدادات';
$lang['_header_dokuwiki']      = 'اعدادات دوكو ويكي';
$lang['_header_plugin']        = 'اعدادات الملحقات';
$lang['_header_template']      = 'اعدادات القوالب';
$lang['_header_undefined']     = 'اعدادات غير محددة';
$lang['_basic']                = 'اعدادات اساسية';
$lang['_display']              = 'اعدادات العرض';
$lang['_authentication']       = 'اعدادات المواثقة';
$lang['_anti_spam']            = 'اعدادات مضاد النفاية';
$lang['_editing']              = 'اعدادات التحرير';
$lang['_links']                = 'اعدادات الروابط';
$lang['_media']                = 'اعدادات الوسائط';
$lang['_notifications']        = 'اعدادات التنبيه';
$lang['_advanced']             = 'اعدادات متقدمة';
$lang['_network']              = 'اعدادات الشبكة';
$lang['_msg_setting_undefined'] = 'لا بيانات إعدادات.';
$lang['_msg_setting_no_class'] = 'لا صنف إعدادات.';
$lang['_msg_setting_no_default'] = 'لا قيمة افتراضية.';
$lang['title']                 = 'عنوان الويكي';
$lang['start']                 = 'اسم صفحة البداية';
$lang['lang']                  = 'لغة الواجهة';
$lang['template']              = 'القالب';
$lang['tagline']               = 'Tagline (في حال دعم القالب له)
';
$lang['sidebar']               = 'اسم صفحة الشريط الجانبي (في حال دعم القالب له). تركه فارغا يعطل الشريط الجانبي.';
$lang['license']               = 'تحت أي رخصة تريد اصدار المحتوى؟';
$lang['savedir']               = 'دليل حفظ البيانات';
$lang['basedir']               = 'مسار الخادوم (مثال. <code>/dokuwiki/</code>) اترك فارغا للاكتشاف التلقائي.';
$lang['baseurl']               = 'عنوان الخادوم (مثال. <code>http://www.yourserver.com</code>). اترك فارغا للاكتشاف التلقائي.';
$lang['cookiedir']             = 'مسار الكعكات. اترك فارغا لاستخدام baseurl.';
$lang['dmode']                 = 'نمط انشاء المجلدات';
$lang['fmode']                 = 'نمط انشاء الملفات';
$lang['allowdebug']            = 'مكّن التنقيح <b>عطّلها إن لم تكن بحاجلة لها!</b>';
$lang['recent']                = 'أحدث التغييرات';
$lang['recent_days']           = 'مدة إبقاء أحدث التغييرات (ايام)';
$lang['breadcrumbs']           = 'عدد العناقيد للزيارات';
$lang['youarehere']            = 'عناقيد هرمية';
$lang['fullpath']              = 'اظهر المحتوى الكامل للصفحات في ';
$lang['typography']            = 'اعمل استبدالات طبوغرافية';
$lang['dformat']               = 'تنسيق التاريخ (انظر وظيفة PHP,s <a href="http://php.net/strftime">strftime</a>)';
$lang['signature']             = 'التوقيع';
$lang['showuseras']            = 'الذي يعرض لاظهار المستخدم الذي قام بآخر تحرير لصفحة';
$lang['toptoclevel']           = 'المستوى الأعلى لمحتويات الجدول';
$lang['tocminheads']           = 'الحد الأدنى من الترويسات لبناء جدول المحتويات';
$lang['maxtoclevel']           = 'المستوى الأقصى لمحتويات الجدول';
$lang['maxseclevel']           = 'المستوى الأقصى لتحرير القسم';
$lang['camelcase']             = 'استخدم CamelCase للروابط';
$lang['deaccent']              = 'نظّف اسماء الصفحات';
$lang['useheading']            = 'استخدم اول ترويسة كأسم للصفحة';
$lang['sneaky_index']          = 'افتراضيا، ستعرض دوكو ويكي كل اسماء النطاقات في عرض الفهرس. تفعيل هذا الخيار سيخفي مالا يملك المستخدم صلاحية قراءته. قد يؤدي هذا إلى اخفاء نطاقات فرعية متاحة. وقد يؤدي لجعل صفحة الفهرس معطلة في بعض اعدادات ACL.';
$lang['hidepages']             = 'أخف الصفحات المنطبق عليها (تعابير شرطية)';
$lang['useacl']                = 'استخدم قائمة التحم بالوصول';
$lang['autopasswd']            = 'ولد كلمات سر تلقائيا';
$lang['authtype']              = 'آلية المواثقة';
$lang['passcrypt']             = 'نمط تشفير كلمة السر';
$lang['defaultgroup']          = 'المجموعة الافتراضية';
$lang['superuser']             = 'مجموعة المستخدم المتفوق أو مستخدم أو قائمة مفصولة بالفاصلة مستخدم1،@مجموعة، مستخدم2 صلاحيتهم الوصول الكامل لكل الصفحات و الوظائف بغض النظر عن اعدادات ACL';
$lang['manager']               = 'مجموعة المدراء أو مستخدم أو قائمة مفصولة بالفاصلة مستخدم1،@مجموعة، مستخدم2 صلاحيتهم بعض الوظائف الادارية';
$lang['profileconfirm']        = 'اكد تغيير اللاحة بكلمة المرور';
$lang['rememberme']            = 'اسمح بكعكات الدخول الدائم (تذكرني)';
$lang['disableactions']        = 'عطّل اجراءات دوكو ويكي';
$lang['disableactions_check']  = 'تحقق';
$lang['disableactions_subscription'] = 'اشترك/الغ الاشتراك';
$lang['disableactions_wikicode'] = 'اعرض المصدر/صدّر صرفا';
$lang['disableactions_other']  = 'اجراءات أخرى (مفصولة بالفاصلة)';
$lang['auth_security_timeout'] = 'زمن انتهاء أمان المواثقة (ثوان)';
$lang['securecookie']          = 'هل يفرض على كعكات التصفح المعدة عبر HTTPS ان ترسل فقط عبر HTTPS من قبل المتصفح؟ عطل هذا إن كان الولوج للويكي مؤمنا فقط عبر SSL لكن تصفح الويكي غير مؤمن.';
$lang['remote']                = 'مكّن نظام API البعيد. يسمح هذا لبرامج أخرى بالوصول للويكي عبر XML-RPC أو آليات أخرى.';
$lang['remoteuser']            = 'احصر الوصول البعيد ل API لمستخدمين ومجموعات يفصل بينها بالفاصلة هنا. اترك فارغا لتمكين الجميع.';
$lang['usewordblock']          = 'احجز الغثاء بناء على قائمة كلمات';
$lang['relnofollow']           = 'استخدم rel="nofollow" للروابط الخارجية';
$lang['indexdelay']            = 'التأخير قبل الفهرسة (ثوان)';
$lang['mailguard']             = 'عناوين بريدية مبهمة';
$lang['iexssprotect']          = 'تحقق الملفات المرفوعة من احتمال وجود أكواد جافاسكربت أو HTML ضارة';
$lang['usedraft']              = 'احفظ المسودة تلقائيا أثناء التحرير';
$lang['locktime']              = 'الحد الأعظمي لقفل الملف (ثوان)';
$lang['cachetime']             = 'الحد الأعظم لعمر المخُبأ (ثوان)';
$lang['target____wiki']        = 'النافذة الهدف للروابط الداخلية';
$lang['target____interwiki']   = 'النافذة الهدف للروابط الممرة interwiki';
$lang['target____extern']      = 'النافذة الهدف للروابط الخارجية';
$lang['target____media']       = 'النافذة الهدف لروابط الوسائط';
$lang['target____windows']     = 'النافذة الهدف لروابط النوافذ';
$lang['mediarevisions']        = 'تفعيل إصدارات الوسائط؟';
$lang['refcheck']              = 'التحقق من مرجع الوسائط';
$lang['gdlib']                 = 'اصدار مكتبة GD';
$lang['im_convert']            = 'المسار إلى اداة تحويل ImageMagick';
$lang['jpg_quality']           = 'دقة ضغط JPG (0-100)';
$lang['fetchsize']             = 'الحجم الأعظمي (بايت) ل fetch.php لتنزيله من الخارج';
$lang['subscribers']           = 'مكن دعم اشتراك الصفحة';
$lang['subscribe_time']        = 'المهلة بعد ارسال قوائم الاشتراكات والملخصات (ثوان); هذا يجب أن يكون أقل من الوقت المخصص في أيام أحدث التغييرات.';
$lang['notify']                = 'ارسل تنبيهات التغيير لهذا البريد';
$lang['registernotify']        = 'ارسل بيانات عن المستخدمين المسجلين جديدا لهذا البريد';
$lang['mailfrom']              = 'البريد الالكتروني ليستخدم للرسائل الآلية';
$lang['mailprefix']            = 'بادئة موضوع البريد لتستخدم مع الرسائل الآلية';
$lang['sitemap']               = 'ولد خرائط موقع جوجل (أيام)';
$lang['rss_type']              = 'نوع تلقيمات XML';
$lang['rss_linkto']            = 'تلقيمات XML توصل إلى';
$lang['rss_content']           = 'مالذي يعرض في عناصر تلقيمات XML؟';
$lang['rss_update']            = 'تحديث تلقيم XML (ثوان)';
$lang['rss_show_summary']      = 'تلقيم XML يظهر ملخصا في العنوان';
$lang['rss_media']             = 'مانوع التغييرات التي ستدرج في تغذية XML؟';
$lang['updatecheck']           = 'تحقق من التحديثات و تنبيهات الأمان؟ دوكو ويكي ستحتاج للاتصال ب update.dokuwiki.org لأجل ذلك';
$lang['userewrite']            = 'استعمل عناوين URLs جميلة';
$lang['useslash']              = 'استخدم الشرطة كفاصل النطاق في العناوين';
$lang['sepchar']               = 'فاصل كلمة اسم الصفحة';
$lang['canonical']             = 'استخدم العناوين الشائعة كاملة';
$lang['fnencode']              = 'نظام ترميز اسماء الملفات بغير الأسكي.';
$lang['autoplural']            = 'تحقق من صيغ الجمع في الروابط';
$lang['compression']           = 'طريقة الغضط لملفات attic';
$lang['gzip_output']           = 'استخدم ترميز-محتوى gzip ل xhtml';
$lang['compress']              = 'رُص مخرجات CSS و جافا سكربت';
$lang['cssdatauri']            = 'الحجم بالبايتات للصور المذكورة في CSS التي ستُضمن في صفحة-التنسيق لخفض طلبات HTTP. <code>400</code> إلى <code>600</code> بايت تعد قيمة جيدة. اضبط إلى <code>0</code> لتعطلها.';
$lang['send404']               = 'ارسل "HTTP 404/Page Not Found" للصفحات غير الموجودة';
$lang['broken_iua']            = 'هل الوظيفة ignore_user_abort معطلة على جهازك؟ قد يؤدي ذلك لتعطيل فهرسة البحث. IIS+PHP/CGI تعرف بأنها لاتعمل. أنظر <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">العلة 852</a> لمزيد من المعلومات.';
$lang['xsendfile']             = 'استخدم ترويسة X-Sendfile لتمكين خادم الوب من تقديم ملفات ثابتة؟ يجب أن يكون خادم الوب داعما له.';
$lang['renderer_xhtml']        = 'المحرك ليستخدم لمخرجات الويكي الأساسية وفق (xhtml).';
$lang['renderer__core']        = '%s (نواة دوكو ويكي)';
$lang['renderer__plugin']      = '%s (ملحق)';
$lang['proxy____host']         = 'اسم خادوم الوكيل';
$lang['proxy____port']         = 'منفذ الوكيل';
$lang['proxy____user']         = 'اسم مستخدم الوكيل';
$lang['proxy____pass']         = 'كلمة سر الوكيل';
$lang['proxy____ssl']          = 'استخدم ssl للاتصال بالوكيل';
$lang['proxy____except']       = 'تعبير شرطي لمقابلة العناوين التي ستتجاوز البروكسي.';
$lang['license_o_']            = 'غير مختار';
$lang['typography_o_0']        = 'لاشيء';
$lang['typography_o_1']        = 'استبعاد الاقتباس المفرد';
$lang['typography_o_2']        = 'تضمين علامات اقتباس مفردة (قد لا يعمل دائما)';
$lang['userewrite_o_0']        = 'لاشيء';
$lang['userewrite_o_1']        = '.htaccess';
$lang['userewrite_o_2']        = 'دو';
$lang['deaccent_o_0']          = 'معطل';
$lang['deaccent_o_1']          = 'أزل اللهجة';
$lang['deaccent_o_2']          = 'اجعلها لاتينية';
$lang['gdlib_o_0']             = 'مكتبة GD غير متوفرة';
$lang['gdlib_o_1']             = 'الاصدار 1.x';
$lang['gdlib_o_2']             = 'اكتشاف تلقائي';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'أتوم 0.3';
$lang['rss_type_o_atom1']      = 'أتوم 1.0';
$lang['rss_content_o_abstract'] = 'خلاصة';
$lang['rss_content_o_diff']    = 'الفروق الموحدة';
$lang['rss_content_o_htmldiff'] = 'جدول الفروق بهيئة HTML';
$lang['rss_content_o_html']    = 'محتوى HTML الكامل للصفحة';
$lang['rss_linkto_o_diff']     = 'عرض الاختلافات';
$lang['rss_linkto_o_page']     = 'الصفحة المعدلة';
$lang['rss_linkto_o_rev']      = 'قائمة بالمراجعات';
$lang['rss_linkto_o_current']  = 'الصفحة الحالية';
$lang['compression_o_0']       = 'لا شيء';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'لا تستخدم';
$lang['xsendfile_o_1']         = 'ترويسة lighttpd مملوكة (قبل الاصدار 1.5)';
$lang['xsendfile_o_2']         = 'ترويسة X-Sendfile قياسية';
$lang['xsendfile_o_3']         = 'ترويسة Nginx X-Accel-Redirect مملوكة';
$lang['showuseras_o_loginname'] = 'اسم الدخول';
$lang['showuseras_o_username'] = 'اسم المستخدم الكامل';
$lang['showuseras_o_email']    = 'عنوان بريد المستخدم (مبهم تبعا لاعدادات حارس_البريد)';
$lang['showuseras_o_email_link'] = 'عنوان بريد المستخدم كـ مالتيو: رابط';
$lang['useheading_o_0']        = 'أبدا';
$lang['useheading_o_navigation'] = 'التنقل فقط';
$lang['useheading_o_content']  = 'محتوى الويكي فقط';
$lang['useheading_o_1']        = 'دائما';
$lang['readdircache']          = 'المدة القصوى لتخزين ';
